package com.philisense.www.controller.app;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.ProOperlogService;
import com.philisense.www.annotation.log.OperateLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
        @RequestMapping(CommonConst.APP_REST_SERVICE_PREFICX+"prooperlog")
        @Api(tags = "ProOperlogControllerForApp |一个用来操作-{操作日志表}-业务模块的控制器")
public class ProOperlogControllerForApp extends BaseUtilController{

        @Autowired
private ProOperlogService proOperlogService;


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{操作日志表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{操作日志表}-主键删除记录",value = "delete",type = "APP")
public Map<String, Object> deleteByPrimaryKeyForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = proOperlogService.deleteByPrimaryKey(recordid);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{操作日志表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{操作日志表}-主键查询记录",value = "query",type = "APP")
public Map<String, Object> selectByPrimaryKeyForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, proOperlogService.selectByPrimaryKey(recordid));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{操作日志表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象插入记录",value = "insert",type = "APP")
public Map<String, Object>  insertForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

        proOperlogService.insert(map);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{操作日志表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象更新记录",value = "update",type = "APP")
public Map<String, Object>  updateForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = proOperlogService.update(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{操作日志表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象Map删除记录",value = "delete",type = "APP")
public Map<String, Object>  deleteByMapForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = proOperlogService.deleteByMap(map);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{操作日志表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象Map更新记录",value = "update",type = "APP")
public Map<String, Object>  updateByMapForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = proOperlogService.updateByMap(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{操作日志表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象Map查询记录",value = "query",type = "APP")
public Map<String, Object>  getOneForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, proOperlogService.getOne(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{操作日志表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象Map查询所有记录",value = "query",type = "APP")
public Map<String, Object>  getAllForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATALIST_VUE, proOperlogService.getAll(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{操作日志表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象Map分页记录",value = "query",type = "APP")
public Map<String, Object>  queryPageForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int total = proOperlogService.count(map);
        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
        if(total>0){
        datalist = proOperlogService.queryPage(map);
        }
        Map<String, Object> tempresult = new HashMap<String, Object>();
        tempresult.put(DATASUCCESS, SUCCESSFLAG);
        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        tempresult.put(DATALIST_VUE,datalist);
        tempresult.put(DATATOTAL_VUE,total);
        tempresult.put(PAGESIZE_VUE,map.get(PAGESIZE_VUE)!=null?map.get(PAGESIZE_VUE):10);
        tempresult.put(DATACURRENT_VUE,map.get(DATACURRENT_VUE)!=null?map.get(DATACURRENT_VUE):0);
        result.put(DATARESULT, tempresult);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{操作日志表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象Map统计查询总数记录",value = "query",type = "APP")
public Map<String, Object>  countForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATATOTAL_VUE, proOperlogService.count(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{操作日志表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象Map批量插入记录",value = "insert",type = "APP")
public Map<String, Object>  insertBatchForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        for(Map<String, Object> map:list){
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
        }

        proOperlogService.insertBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{操作日志表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象Map批量删除记录",value = "delete",type = "APP")
public Map<String, Object>  deleteBatchForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        proOperlogService.deleteBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{操作日志表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "操作日志记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opername", value = "操作名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "opertype", value = "操作类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "class_method", value = "操作类方法", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_method", value = "方法类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_url", value = "操作url", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_params", value = "操作参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_body", value = "操作body参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "http_header", value = "操作header参数", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "操作内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cost", value = "耗时", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "createip", value = "ip地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createuser", value = "操作用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "createdate", value = "日期", required = true,  dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "client_type", value = "终端类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{操作日志表}-对象Map批量更新记录",value = "update",type = "APP")
public Map<String, Object>  updateBatchForProOperlogForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        proOperlogService.updateBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        }
