package com.philisense.www.controller.app;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.EbookArticlePhotosService;
import com.philisense.www.annotation.log.OperateLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
        @RequestMapping(CommonConst.APP_REST_SERVICE_PREFICX+"ebookarticlephotos")
        @Api(tags = "EbookArticlePhotosControllerForApp |一个用来操作-{在现电子写作内容相册表}-业务模块的控制器")
public class EbookArticlePhotosControllerForApp extends BaseUtilController{

        @Autowired
private EbookArticlePhotosService ebookArticlePhotosService;


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{在现电子写作内容相册表}-主键删除记录",value = "delete",type = "APP")
public Map<String, Object> deleteByPrimaryKeyForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = ebookArticlePhotosService.deleteByPrimaryKey(recordid);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{在现电子写作内容相册表}-主键查询记录",value = "query",type = "APP")
public Map<String, Object> selectByPrimaryKeyForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, ebookArticlePhotosService.selectByPrimaryKey(recordid));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象插入记录",value = "insert",type = "APP")
public Map<String, Object>  insertForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

        ebookArticlePhotosService.insert(map);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象更新记录",value = "update",type = "APP")
public Map<String, Object>  updateForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = ebookArticlePhotosService.update(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象Map删除记录",value = "delete",type = "APP")
public Map<String, Object>  deleteByMapForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = ebookArticlePhotosService.deleteByMap(map);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象Map更新记录",value = "update",type = "APP")
public Map<String, Object>  updateByMapForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = ebookArticlePhotosService.updateByMap(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象Map查询记录",value = "query",type = "APP")
public Map<String, Object>  getOneForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, ebookArticlePhotosService.getOne(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象Map查询所有记录",value = "query",type = "APP")
public Map<String, Object>  getAllForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATALIST, ebookArticlePhotosService.getAll(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象Map分页记录",value = "query",type = "APP")
public Map<String, Object>  queryPageForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+""):0;
        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
        int pageStart = currentPage*pageSize ;

        map.put(PAGESIZE,pageSize);
        map.put(PAGESTART,pageStart);


                int total = ebookArticlePhotosService.count(map);
        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
        if(total>0){
        datalist = ebookArticlePhotosService.queryPage(map);
        }
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATALIST,datalist);
        Map<String, Object> pagemode = new HashMap<String, Object>();
        pagemode.put(DATATOTAL,total);
        pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
        pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
        result.put(PAGINATION,pagemode);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象Map统计查询总数记录",value = "query",type = "APP")
public Map<String, Object>  countForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATATOTAL, ebookArticlePhotosService.count(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象Map批量插入记录",value = "insert",type = "APP")
public Map<String, Object>  insertBatchForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        for(Map<String, Object> map:list){
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
        }

        ebookArticlePhotosService.insertBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象Map批量删除记录",value = "delete",type = "APP")
public Map<String, Object>  deleteBatchForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        ebookArticlePhotosService.deleteBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{在现电子写作内容相册表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "article_id", value = "文章id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_client", value = "图片显示终端", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "images_type", value = "图片缩略,微图,大图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "type_store", value = "图片存储位置,本地，七牛，又拍云，百度云，腾讯云", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_commonid", value = "公共内容id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "color_id", value = "颜色规格值id", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "goods_image", value = "图片原图", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_samll", value = "图片封面", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "goods_image_sort", value = "排序", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "is_default", value = "默认主题，1是，0否", required = true, dataType = "int", dataTypeClass = int.class)
        })
        @OperateLog(name = "根据-{在现电子写作内容相册表}-对象Map批量更新记录",value = "update",type = "APP")
public Map<String, Object>  updateBatchForEbookArticlePhotosForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        ebookArticlePhotosService.updateBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        }
