package com.philisense.www.controller.app;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.EbookArticleTypeService;
import com.philisense.www.annotation.log.OperateLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(CommonConst.APP_REST_SERVICE_PREFICX+"ebookarticletype")
@Api(tags = "EbookArticleTypeControllerForApp |一个用来操作-{文章分类表}-业务模块的控制器")
public class EbookArticleTypeControllerForApp extends BaseUtilController{

        @Autowired
        private EbookArticleTypeService ebookArticleTypeService;


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{文章分类表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{文章分类表}-主键删除记录",value = "delete",type = "APP")
        public Map<String, Object> deleteByPrimaryKeyForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = ebookArticleTypeService.deleteByPrimaryKey(recordid);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{文章分类表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{文章分类表}-主键查询记录",value = "query",type = "APP")
        public Map<String, Object> selectByPrimaryKeyForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, ebookArticleTypeService.selectByPrimaryKey(recordid));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{文章分类表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象插入记录",value = "insert",type = "APP")
        public Map<String, Object>  insertForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

        ebookArticleTypeService.insert(map);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{文章分类表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象更新记录",value = "update",type = "APP")
        public Map<String, Object>  updateForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = ebookArticleTypeService.update(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{文章分类表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象Map删除记录",value = "delete",type = "APP")
        public Map<String, Object>  deleteByMapForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = ebookArticleTypeService.deleteByMap(map);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{文章分类表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象Map更新记录",value = "update",type = "APP")
        public Map<String, Object>  updateByMapForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = ebookArticleTypeService.updateByMap(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{文章分类表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象Map查询记录",value = "query",type = "APP")
        public Map<String, Object>  getOneForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, ebookArticleTypeService.getOne(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{文章分类表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象Map查询所有记录",value = "query",type = "APP")
        public Map<String, Object>  getAllForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATALIST, ebookArticleTypeService.getAll(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{文章分类表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象Map分页记录",value = "query",type = "APP")
        public Map<String, Object>  queryPageForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+""):0;
        int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
        int pageStart = currentPage*pageSize ;

        map.put(PAGESIZE,pageSize);
        map.put(PAGESTART,pageStart);
        int total = ebookArticleTypeService.count(map);
        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
        if(total>0){
        datalist = ebookArticleTypeService.queryPage(map);
        }
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATALIST,datalist);
        Map<String, Object> pagemode = new HashMap<String, Object>();
        pagemode.put(DATATOTAL,total);
        pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
        pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
        result.put(PAGINATION,pagemode);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{文章分类表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象Map统计查询总数记录",value = "query",type = "APP")
        public Map<String, Object>  countForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATATOTAL, ebookArticleTypeService.count(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{文章分类表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象Map批量插入记录",value = "insert",type = "APP")
        public Map<String, Object>  insertBatchForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        for(Map<String, Object> map:list){
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
        }

        ebookArticleTypeService.insertBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{文章分类表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象Map批量删除记录",value = "delete",type = "APP")
        public Map<String, Object>  deleteBatchForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        ebookArticleTypeService.deleteBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{文章分类表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "description", value = "描述", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层级", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "树叶", required = true, dataType = "int", dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = "create_user_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "create_time", value = "创建时间", required = true, dataType = "Date", dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{文章分类表}-对象Map批量更新记录",value = "update",type = "APP")
        public Map<String, Object>  updateBatchForEbookArticleTypeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        ebookArticleTypeService.updateBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        }
