package com.philisense.www.controller.app;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.ProMenuService;
import com.philisense.www.annotation.log.OperateLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
        @RequestMapping(CommonConst.APP_REST_SERVICE_PREFICX+"promenu")
        @Api(tags = "ProMenuControllerForApp |一个用来操作-{菜单表}-业务模块的控制器")
public class ProMenuControllerForApp extends BaseUtilController{

        @Autowired
private ProMenuService proMenuService;


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{菜单表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{菜单表}-主键删除记录",value = "delete",type = "APP")
public Map<String, Object> deleteByPrimaryKeyForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = proMenuService.deleteByPrimaryKey(recordid);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{菜单表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{菜单表}-主键查询记录",value = "query",type = "APP")
public Map<String, Object> selectByPrimaryKeyForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, proMenuService.selectByPrimaryKey(recordid));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{菜单表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象插入记录",value = "insert",type = "APP")
public Map<String, Object>  insertForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

        proMenuService.insert(map);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{菜单表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象更新记录",value = "update",type = "APP")
public Map<String, Object>  updateForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = proMenuService.update(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{菜单表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象Map删除记录",value = "delete",type = "APP")
public Map<String, Object>  deleteByMapForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = proMenuService.deleteByMap(map);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{菜单表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象Map更新记录",value = "update",type = "APP")
public Map<String, Object>  updateByMapForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = proMenuService.updateByMap(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{菜单表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象Map查询记录",value = "query",type = "APP")
public Map<String, Object>  getOneForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, proMenuService.getOne(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{菜单表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象Map查询所有记录",value = "query",type = "APP")
public Map<String, Object>  getAllForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATALIST_VUE, proMenuService.getAll(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{菜单表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象Map分页记录",value = "query",type = "APP")
public Map<String, Object>  queryPageForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        int currentPage = map.get(DATACURRENT_VUE)!=null?Integer.parseInt(map.get(DATACURRENT_VUE)+""):0;
        int pageSize = map.get(PAGESIZE_VUE)!=null?Integer.parseInt(map.get(PAGESIZE_VUE)+""):10;
        int pageStart = currentPage*pageSize ;

        map.put(PAGESIZE_VUE,pageSize);
        map.put(PAGESTART,pageStart);

        int total = proMenuService.count(map);
        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
        if(total>0){
        datalist = proMenuService.queryPage(map);
        }
        Map<String, Object> tempresult = new HashMap<String, Object>();
        tempresult.put(DATASUCCESS, SUCCESSFLAG);
        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        tempresult.put(DATALIST_VUE,datalist);
        tempresult.put(DATATOTAL_VUE,total);
        tempresult.put(PAGESIZE_VUE,map.get(PAGESIZE_VUE)!=null?map.get(PAGESIZE_VUE):10);
        tempresult.put(DATACURRENT_VUE,map.get(DATACURRENT_VUE)!=null?map.get(DATACURRENT_VUE):0);
        result.put(DATARESULT, tempresult);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{菜单表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象Map统计查询总数记录",value = "query",type = "APP")
public Map<String, Object>  countForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATATOTAL_VUE, proMenuService.count(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{菜单表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象Map批量插入记录",value = "insert",type = "APP")
public Map<String, Object>  insertBatchForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        for(Map<String, Object> map:list){
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
        }

        proMenuService.insertBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{菜单表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象Map批量删除记录",value = "delete",type = "APP")
public Map<String, Object>  deleteBatchForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        proMenuService.deleteBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{菜单表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "recordid", value = "菜单Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "id", value = "菜单编号", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "text", value = "菜单名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parentid", value = "父菜单ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "indexs", value = "位置", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "sequences", value = "顺序", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "href", value = "链接", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hreftarget", value = "弹出目标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "enable", value = "是否可用", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "valid", value = "是否有效", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "systemid", value = "系统ID", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "isframe", value = "是否frame", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "leaftype", value = "节点级别", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "component", value = "前端动态组件路径", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "i18n_name", value = "菜单国际化", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "redirect", value = "重定向路由地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideInMenu", value = "本节隐藏", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "hideChildrenInMenu", value = "隐藏父节点的孩子", required = true,  dataTypeClass = String.class),
                @ApiImplicitParam(paramType = "body", name = "hideLayout", value = "是否使用layout布局", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{菜单表}-对象Map批量更新记录",value = "update",type = "APP")
public Map<String, Object>  updateBatchForProMenuForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        proMenuService.updateBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        }
