package com.philisense.www.controller.app;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.ProOrgService;
import com.philisense.www.annotation.log.OperateLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(CommonConst.APP_REST_SERVICE_PREFICX + "proorg")
@Api(tags = "ProOrgControllerForApp |一个用来操作-{机构表}-业务模块的控制器")
public class ProOrgControllerForApp extends BaseUtilController {

    @Autowired
    private ProOrgService proOrgService;


    @GetMapping("/delete")
    @ApiOperation(value = "根据-{机构表}-主键删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParam(paramType = "query", name = "recordid", value = "记录主键", required = true, dataTypeClass = String.class)
    @OperateLog(name = "根据-{机构表}-主键删除记录", value = "delete", type = "APP")
    public Map<String, Object> deleteByPrimaryKeyForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestParam String recordid) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            int flag = proOrgService.deleteByPrimaryKey(recordid);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @GetMapping("/get")
    @ApiOperation(value = "根据-{机构表}-主键查询记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParam(paramType = "query", name = "recordid", value = "记录主键", required = true, dataTypeClass = String.class)
    @OperateLog(name = "根据-{机构表}-主键查询记录", value = "query", type = "APP")
    public Map<String, Object> selectByPrimaryKeyForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestParam String recordid) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARECORD, proOrgService.selectByPrimaryKey(recordid));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/insert")
    @ApiOperation(value = "根据-{机构表}-对象插入记录", notes = "成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象插入记录", value = "insert", type = "APP")
    public Map<String, Object> insertForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

            proOrgService.insert(map);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/update")
    @ApiOperation(value = "根据-{机构表}-对象更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象更新记录", value = "update", type = "APP")
    public Map<String, Object> updateForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


            int flag = proOrgService.update(map);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/deleteByMap")
    @ApiOperation(value = "根据-{机构表}-对象Map删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象Map删除记录", value = "delete", type = "APP")
    public Map<String, Object> deleteByMapForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            int flag = proOrgService.deleteByMap(map);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/updateByMap")
    @ApiOperation(value = "根据-{机构表}-对象Map更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象Map更新记录", value = "update", type = "APP")
    public Map<String, Object> updateByMapForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


            int flag = proOrgService.updateByMap(map);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/getOne")
    @ApiOperation(value = "根据-{机构表}-对象Map查询记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象Map查询记录", value = "query", type = "APP")
    public Map<String, Object> getOneForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARECORD, proOrgService.getOne(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/getAll")
    @ApiOperation(value = "根据-{机构表}-对象Map查询所有记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象Map查询所有记录", value = "query", type = "APP")
    public Map<String, Object> getAllForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATALIST_VUE, proOrgService.getAll(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/queryPage")
    @ApiOperation(value = "根据-{机构表}-对象Map分页记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象Map分页记录", value = "query", type = "APP")
    public Map<String, Object> queryPageForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            int currentPage = map.get(DATACURRENT_VUE) != null ? Integer.parseInt(map.get(DATACURRENT_VUE) + "") : 0;
            int pageSize = map.get(PAGESIZE_VUE) != null ? Integer.parseInt(map.get(PAGESIZE_VUE) + "") : 10;
            int pageStart = currentPage * pageSize;

            map.put(PAGESIZE_VUE, pageSize);
            map.put(PAGESTART, pageStart);

            int total = proOrgService.count(map);
            List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
            if (total > 0) {
                datalist = proOrgService.queryPage(map);
            }
            Map<String, Object> tempresult = new HashMap<String, Object>();
            tempresult.put(DATASUCCESS, SUCCESSFLAG);
            tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            tempresult.put(DATALIST_VUE, datalist);
            tempresult.put(DATATOTAL_VUE, total);
            tempresult.put(PAGESIZE_VUE, map.get(PAGESIZE_VUE) != null ? map.get(PAGESIZE_VUE) : 10);
            tempresult.put(DATACURRENT_VUE, map.get(DATACURRENT_VUE) != null ? map.get(DATACURRENT_VUE) : 0);
            result.put(DATARESULT, tempresult);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/count")
    @ApiOperation(value = "根据-{机构表}-对象Map统计查询总数记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象Map统计查询总数记录", value = "query", type = "APP")
    public Map<String, Object> countForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATATOTAL_VUE, proOrgService.count(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/insertBatch")
    @ApiOperation(value = "根据-{机构表}-对象Map批量插入记录", notes = "成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象Map批量插入记录", value = "insert", type = "APP")
    public Map<String, Object> insertBatchForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            for (Map<String, Object> map : list) {
                map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
            }

            proOrgService.insertBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/deleteBatch")
    @ApiOperation(value = "根据-{机构表}-对象Map批量删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象Map批量删除记录", value = "delete", type = "APP")
    public Map<String, Object> deleteBatchForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            proOrgService.deleteBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/updateBatch")
    @ApiOperation(value = "根据-{机构表}-对象Map批量更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "org_id", value = "机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_name", value = "机构名称", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "org_code", value = "机构code", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父机构Id", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true, dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true, dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{机构表}-对象Map批量更新记录", value = "update", type = "APP")
    public Map<String, Object> updateBatchForProOrgForApp(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


            proOrgService.updateBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/getProOrgTreeByLevelCode")
    @ApiOperation(value = "查询所有部门数据根据层次码", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父部门ID", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "查询所有部门数据根据层次码", value = "query", type = "PC")
    public Map<String, Object> getProDeptTreeByLevelCode(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            String parentid = map.get("parentid") + "";

            List<Map<String, Object>> treedata = proOrgService.getProOrgTreeByLevelCode(map);

            List<Map<String, Object>> parenttreedata = new ArrayList<Map<String, Object>>();

            if (null != treedata && treedata.size() > 0) {

                //一级树节点
                for (Map<String, Object> tree : treedata) {
                    tree.put("key", tree.get("id"));
                    tree.put("title", tree.get("title"));

                    if (tree.get("parentid").equals(parentid)) {
                        parenttreedata.add(tree);
                    }
                }

                //二级树节点
                List<Map<String, Object>> second_treedata = new ArrayList<Map<String, Object>>();//二级树节点
                for (Map<String, Object> ptree : parenttreedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("id"));
                        tree.put("title", tree.get("title"));
                        if (tree.get("parentid").equals(ptree.get("id"))) {
                            second_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                List<Map<String, Object>> third_treedata = new ArrayList<Map<String, Object>>();//三级树节点
                List<Map<String, Object>> fourth_treedata = new ArrayList<Map<String, Object>>();//四级树节点
                List<Map<String, Object>> fifth_treedata = new ArrayList<Map<String, Object>>();//五级树节点
                List<Map<String, Object>> sixth_treedata = new ArrayList<Map<String, Object>>();//六级树节点

                //三级树节点
                for (Map<String, Object> ptree : second_treedata) {
                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();

                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("id"));
                        tree.put("title", tree.get("title"));
                        if (tree.get("parentid").equals(ptree.get("id"))) {
                            third_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                //四级树节点
                for (Map<String, Object> ptree : third_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("id"));
                        tree.put("title", tree.get("title"));
                        if (tree.get("parentid").equals(ptree.get("id"))) {
                            fourth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                //五级树节点
                for (Map<String, Object> ptree : fourth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("id"));
                        tree.put("title", tree.get("title"));
                        if (tree.get("parentid").equals(ptree.get("id"))) {
                            fifth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

                //六级树节点
                for (Map<String, Object> ptree : fifth_treedata) {
                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("id"));
                        tree.put("title", tree.get("title"));
                        if (tree.get("parentid").equals(ptree.get("id"))) {
                            sixth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }

            }

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATALIST_VUE, parenttreedata);

        } catch (Exception e) {

            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

}
