package com.philisense.www.controller.app;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.ProSystemService;
import com.philisense.www.annotation.log.OperateLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
        @RequestMapping(CommonConst.APP_REST_SERVICE_PREFICX+"prosystem")
        @Api(tags = "ProSystemControllerForApp |一个用来操作-{子系统表}-业务模块的控制器")
public class ProSystemControllerForApp extends BaseUtilController{

        @Autowired
private ProSystemService proSystemService;


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{子系统表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{子系统表}-主键删除记录",value = "delete",type = "APP")
public Map<String, Object> deleteByPrimaryKeyForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = proSystemService.deleteByPrimaryKey(recordid);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{子系统表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{子系统表}-主键查询记录",value = "query",type = "APP")
public Map<String, Object> selectByPrimaryKeyForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, proSystemService.selectByPrimaryKey(recordid));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{子系统表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象插入记录",value = "insert",type = "APP")
public Map<String, Object>  insertForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

        proSystemService.insert(map);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{子系统表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象更新记录",value = "update",type = "APP")
public Map<String, Object>  updateForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = proSystemService.update(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{子系统表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象Map删除记录",value = "delete",type = "APP")
public Map<String, Object>  deleteByMapForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = proSystemService.deleteByMap(map);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{子系统表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象Map更新记录",value = "update",type = "APP")
public Map<String, Object>  updateByMapForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = proSystemService.updateByMap(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{子系统表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象Map查询记录",value = "query",type = "APP")
public Map<String, Object>  getOneForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, proSystemService.getOne(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{子系统表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象Map查询所有记录",value = "query",type = "APP")
public Map<String, Object>  getAllForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATALIST_VUE, proSystemService.getAll(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{子系统表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象Map分页记录",value = "query",type = "APP")
public Map<String, Object>  queryPageForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        int currentPage = map.get(DATACURRENT_VUE)!=null?Integer.parseInt(map.get(DATACURRENT_VUE)+""):0;
        int pageSize = map.get(PAGESIZE_VUE)!=null?Integer.parseInt(map.get(PAGESIZE_VUE)+""):10;
        int pageStart = currentPage*pageSize ;

        map.put(PAGESIZE_VUE,pageSize);
        map.put(PAGESTART,pageStart);

        int total = proSystemService.count(map);
        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
        if(total>0){
        datalist = proSystemService.queryPage(map);
        }
        Map<String, Object> tempresult = new HashMap<String, Object>();
        tempresult.put(DATASUCCESS, SUCCESSFLAG);
        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        tempresult.put(DATALIST_VUE,datalist);
        tempresult.put(DATATOTAL_VUE,total);
        tempresult.put(PAGESIZE_VUE,map.get(PAGESIZE_VUE)!=null?map.get(PAGESIZE_VUE):10);
        tempresult.put(DATACURRENT_VUE,map.get(DATACURRENT_VUE)!=null?map.get(DATACURRENT_VUE):0);
        result.put(DATARESULT, tempresult);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{子系统表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象Map统计查询总数记录",value = "query",type = "APP")
public Map<String, Object>  countForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATATOTAL_VUE, proSystemService.count(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{子系统表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象Map批量插入记录",value = "insert",type = "APP")
public Map<String, Object>  insertBatchForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        for(Map<String, Object> map:list){
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
        }

        proSystemService.insertBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{子系统表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象Map批量删除记录",value = "delete",type = "APP")
public Map<String, Object>  deleteBatchForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        proSystemService.deleteBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{子系统表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "记录id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "name", value = "系统名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "ename", value = "英文名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "contextpath", value = "上下文", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "tableprefix", value = "表名前缀", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "logo", value = "系统标志", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "icon", value = "系统图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "version", value = "版本", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "builddate", value = "构建日期", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "status", value = "状态", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "orderid", value = "排序", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "memo", value = "备注", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{子系统表}-对象Map批量更新记录",value = "update",type = "APP")
public Map<String, Object>  updateBatchForProSystemForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        proSystemService.updateBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        }
