package com.philisense.www.controller.app;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.ProTenantService;
import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.pojos.entity.ProTenant;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import java.math.BigDecimal;

@RestController
@RequestMapping(CommonConst.APP_REST_SERVICE_PREFICX+"protenant")
@Api(tags = "ProTenantControllerForApp |一个用来操作-{租户表}-业务模块的控制器")
public class ProTenantControllerForApp extends BaseUtilController{

        @Autowired
        private ProTenantService proTenantService;


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{租户表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{租户表}-主键删除记录",value = "delete",type = "APP")
        public Map<String, Object> deleteByPrimaryKeyForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                int flag = proTenantService.deleteByPrimaryKey(recordid);
                if(1<=flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{租户表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{租户表}-主键查询记录",value = "query",type = "APP")
        public Map<String, Object> selectByPrimaryKeyForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATARECORD, proTenantService.selectByPrimaryKey(recordid));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{租户表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象插入记录",value = "insert",type = "APP")
        public Map<String, Object>  insertForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

                proTenantService.insert(map);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{租户表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象更新记录",value = "update",type = "APP")
        public Map<String, Object>  updateForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                Map<String, Object> paramsmap = proTenantService.selectByPrimaryKey(map.get("id")+"");

                int flag = 0;

                if( null!=paramsmap &&paramsmap.size()>0) {
                paramsmap.putAll(map);
                flag = proTenantService.update(paramsmap);
                }

                if(1<=flag){
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{租户表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map删除记录",value = "delete",type = "APP")
        public Map<String, Object>  deleteByMapForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                int flag = proTenantService.deleteByMap(map);
                if(1<=flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{租户表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map更新记录",value = "update",type = "APP")
        public Map<String, Object>  updateByMapForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                int flag = proTenantService.updateByMap(map);
                if(1<=flag){
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{租户表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map查询记录",value = "query",type = "APP")
        public Map<String, Object>  getOneForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATARECORD, proTenantService.getOne(map));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{租户表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map查询所有记录",value = "query",type = "APP")
        public Map<String, Object>  getAllForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST, proTenantService.getAll(map));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{租户表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map分页记录",value = "query",type = "App")
        public Map<String, Object>  queryPageForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                int pageStart = currentPage*pageSize ;


                map.put(PAGESIZE,pageSize);
                map.put(PAGESTART,pageStart);

                int total = proTenantService.count(map);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proTenantService.queryPage(map);
                }
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST,datalist);
                Map<String, Object> pagemode = new HashMap<String, Object>();
                pagemode.put(DATATOTAL,total);
                pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                result.put(PAGINATION,pagemode);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }


        @PostMapping( "/queryPageVue")
        @ApiOperation(value="根据-{租户表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map分页记录",value = "query",type = "App")
        public Map<String, Object>  queryPageVueForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                int currentPage = map.get(DATACURRENT_VUE)!=null?Integer.parseInt(map.get(DATACURRENT_VUE)+"")-1:0;
                int pageSize = map.get(PAGESIZE_VUE)!=null?Integer.parseInt(map.get(PAGESIZE_VUE)+""):10;
                int pageStart = currentPage*pageSize ;


                map.put(PAGESIZE_VUE,pageSize);
                map.put(PAGESTART,pageStart);

                int total = proTenantService.count(map);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proTenantService.queryPage(map);
                }
                Map<String, Object> tempresult = new HashMap<String, Object>();
                tempresult.put(DATASUCCESS, SUCCESSFLAG);
                tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                tempresult.put(DATALIST_VUE,datalist);
                tempresult.put(DATATOTAL_VUE,total);
                tempresult.put(PAGESIZE_VUE,map.get(PAGESIZE_VUE)!=null?map.get(PAGESIZE_VUE):10);
                tempresult.put(DATACURRENT_VUE,map.get(DATACURRENT_VUE)!=null?map.get(DATACURRENT_VUE):0);
                result.put(DATARESULT, tempresult);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }



        @PostMapping( "/queryPageOracle")
        @ApiOperation(value="根据-{租户表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
                        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map分页记录",value = "query",type = "App")
        public Map<String, Object>  queryPageOracleForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+""):1;
                int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                int pageStart = currentPage*pageSize ;


                map.put(PAGESTART,(currentPage-1)*pageSize);
                map.put(PAGEEND,currentPage*pageSize);

                int total = proTenantService.count(map);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proTenantService.queryPage(map);
                }
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST,datalist);
                Map<String, Object> pagemode = new HashMap<String, Object>();
                pagemode.put(DATATOTAL,total);
                pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                result.put(PAGINATION,pagemode);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{租户表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map统计查询总数记录",value = "query",type = "APP")
        public Map<String, Object>  countForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATATOTAL, proTenantService.count(map));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{租户表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map批量插入记录",value = "insert",type = "APP")
        public Map<String, Object>  insertBatchForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                for(Map<String, Object> map:list){
                map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
                }

                proTenantService.insertBatch(list);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{租户表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map批量删除记录",value = "delete",type = "APP")
        public Map<String, Object>  deleteBatchForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                proTenantService.deleteBatch(list);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{租户表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = ProTenant.ID_KEY, value = "id", required = true, dataTypeClass = int.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_CODE_KEY, value = "租户代码", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.TENANT_NAME_KEY, value = "租户名", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.MENOS_KEY, value = "备注", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_ID_KEY, value = "create_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATOR_KEY, value = "创建人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.CREATE_TIME_KEY, value = "创建时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATER_KEY, value = "更新人", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_ID_KEY, value = "update_id", required = true, dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.UPDATE_TIME_KEY, value = "更新时间", required = true, dataTypeClass = Date.class),
        @ApiImplicitParam(paramType="body", name = ProTenant.STATUS_KEY, value = "0正常 9-冻结", required = true, dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{租户表}-对象Map批量更新记录",value = "update",type = "APP")
        public Map<String, Object>  updateBatchForProTenantForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                proTenantService.updateBatch(list);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

}
