package com.philisense.www.controller.app;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.SystemNoticeService;
import com.philisense.www.annotation.log.OperateLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
        @RequestMapping(CommonConst.APP_REST_SERVICE_PREFICX+"systemnotice")
        @Api(tags = "SystemNoticeControllerForApp |一个用来操作-{系统公告}-业务模块的控制器")
public class SystemNoticeControllerForApp extends BaseUtilController{

        @Autowired
private SystemNoticeService systemNoticeService;


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{系统公告}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{系统公告}-主键删除记录",value = "delete",type = "APP")
public Map<String, Object> deleteByPrimaryKeyForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = systemNoticeService.deleteByPrimaryKey(recordid);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{系统公告}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{系统公告}-主键查询记录",value = "query",type = "APP")
public Map<String, Object> selectByPrimaryKeyForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, systemNoticeService.selectByPrimaryKey(recordid));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{系统公告}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象插入记录",value = "insert",type = "APP")
public Map<String, Object>  insertForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));

        systemNoticeService.insert(map);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{系统公告}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象更新记录",value = "update",type = "APP")
public Map<String, Object>  updateForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = systemNoticeService.update(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{系统公告}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象Map删除记录",value = "delete",type = "APP")
public Map<String, Object>  deleteByMapForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        int flag = systemNoticeService.deleteByMap(map);
        if(1<=flag) {
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{系统公告}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象Map更新记录",value = "update",type = "APP")
public Map<String, Object>  updateByMapForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        int flag = systemNoticeService.updateByMap(map);
        if(1<=flag){
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
        }else{
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
        }

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{系统公告}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象Map查询记录",value = "query",type = "APP")
public Map<String, Object>  getOneForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATARECORD, systemNoticeService.getOne(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{系统公告}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象Map查询所有记录",value = "query",type = "APP")
public Map<String, Object>  getAllForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATALIST_VUE, systemNoticeService.getAll(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{系统公告}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象Map分页记录",value = "query",type = "APP")
public Map<String, Object>  queryPageForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        int currentPage = map.get(DATACURRENT_VUE)!=null?Integer.parseInt(map.get(DATACURRENT_VUE)+""):0;
        int pageSize = map.get(PAGESIZE_VUE)!=null?Integer.parseInt(map.get(PAGESIZE_VUE)+""):10;
        int pageStart = currentPage*pageSize ;

        map.put(PAGESIZE_VUE,pageSize);
        map.put(PAGESTART,pageStart);

       int total = systemNoticeService.count(map);
        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
        if(total>0){
        datalist = systemNoticeService.queryPage(map);
        }
        Map<String, Object> tempresult = new HashMap<String, Object>();
        tempresult.put(DATASUCCESS, SUCCESSFLAG);
        tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        tempresult.put(DATALIST_VUE,datalist);
        tempresult.put(DATATOTAL_VUE,total);
        tempresult.put(PAGESIZE_VUE,map.get(PAGESIZE_VUE)!=null?map.get(PAGESIZE_VUE):10);
        tempresult.put(DATACURRENT_VUE,map.get(DATACURRENT_VUE)!=null?map.get(DATACURRENT_VUE):0);
        result.put(DATARESULT, tempresult);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{系统公告}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象Map统计查询总数记录",value = "query",type = "APP")
public Map<String, Object>  countForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
        result.put(DATATOTAL_VUE, systemNoticeService.count(map));
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{系统公告}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象Map批量插入记录",value = "insert",type = "APP")
public Map<String, Object>  insertBatchForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

        for(Map<String, Object> map:list){
        map.put("id", UUID.randomUUID().toString().replaceAll("-", ""));
        }

        systemNoticeService.insertBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{系统公告}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象Map批量删除记录",value = "delete",type = "APP")
public Map<String, Object>  deleteBatchForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
        systemNoticeService.deleteBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{系统公告}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "id", value = "通知id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "title", value = "公告标题", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "content", value = "公告内容", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "url", value = "公告链接地址", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "an_addtime", value = "添加时间", required = true,  dataTypeClass = Date.class)
        })
        @OperateLog(name = "根据-{系统公告}-对象Map批量更新记录",value = "update",type = "APP")
public Map<String, Object>  updateBatchForSystemNoticeForApp(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
        {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


        systemNoticeService.updateBatch(list);
        result.put(DATASUCCESS, SUCCESSFLAG);
        result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        }catch(Exception e){
        result.put(DATASUCCESS, ERRORFLAG);
        result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
        }
        return result;
        }

        }
