package com.philisense.www.controller.web;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.ProAuthorityService;
import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.utils.ActiveUserUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"proauthority")
@Api(tags = "ProAuthorityControllerForWeb|一个用来操作-{角色表}-业务模块的控制器")
public class ProAuthorityControllerForWeb extends BaseUtilController{

        @Autowired
        private ProAuthorityService proAuthorityService;


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{角色表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{角色表}-主键删除记录",value = "delete",type = "PC")
        public Map<String, Object> deleteByPrimaryKeyForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                int flag = proAuthorityService.deleteByPrimaryKey(recordid);
                if(1<=flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{角色表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{角色表}-主键查询记录",value = "query",type = "PC")
        public Map<String, Object> selectByPrimaryKeyForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATARECORD, proAuthorityService.selectByPrimaryKey(recordid));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{角色表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象插入记录",value = "insert",type = "PC")
        public Map<String, Object>  insertForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                String username = request.getParameter("username");
                map.put("auth_id", UUID.randomUUID().toString().replaceAll("-", ""));
                map.put("display", "1");
                map.put("is_system_auth", 1);
                map.put("creator_id", username);

                proAuthorityService.insert(map);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{角色表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                int flag = proAuthorityService.update(map);

                if(1<=flag){
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{角色表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map删除记录",value = "delete",type = "PC")
        public Map<String, Object>  deleteByMapForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                int flag = proAuthorityService.deleteByMap(map);
                if(1<=flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{角色表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateByMapForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                int flag = proAuthorityService.updateByMap(map);
                if(1<=flag){
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{角色表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map查询记录",value = "query",type = "PC")
        public Map<String, Object>  getOneForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATARECORD, proAuthorityService.getOne(map));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{角色表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map查询所有记录",value = "query",type = "PC")
        public Map<String, Object>  getAllForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
                {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST_VUE, proAuthorityService.getAll(map));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{角色表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  queryPageForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                int pageStart = currentPage*pageSize ;


                map.put(PAGESIZE,pageSize);
                map.put(PAGESTART,pageStart);

                int total = proAuthorityService.count(map);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proAuthorityService.queryPage(map);
                }
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST,datalist);
                Map<String, Object> pagemode = new HashMap<String, Object>();
                pagemode.put(DATATOTAL,total);
                pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                result.put(PAGINATION,pagemode);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/queryPageForGrading")
        @ApiOperation(value="根据-{角色表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  queryPageForGradingForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                int pageStart = currentPage*pageSize ;


                map.put(PAGESIZE,pageSize);
                map.put(PAGESTART,pageStart);
                map.put("userId", ActiveUserUtils.getUserId());
                int total = proAuthorityService.count(map);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proAuthorityService.queryPage(map);
                }
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST,datalist);
                Map<String, Object> pagemode = new HashMap<String, Object>();
                pagemode.put(DATATOTAL,total);
                pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                result.put(PAGINATION,pagemode);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }


        @PostMapping( "/queryPageVue")
        @ApiOperation(value="根据-{角色表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  queryPageVueForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                int currentPage = map.get(DATACURRENT_VUE)!=null?Integer.parseInt(map.get(DATACURRENT_VUE)+"")-1:0;
                int pageSize = map.get(PAGESIZE_VUE)!=null?Integer.parseInt(map.get(PAGESIZE_VUE)+""):10;
                int pageStart = currentPage*pageSize ;


                map.put(PAGESIZE_VUE,pageSize);
                map.put(PAGESTART,pageStart);

                int total = proAuthorityService.count(map);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proAuthorityService.queryPage(map);
                }
                Map<String, Object> tempresult = new HashMap<String, Object>();
                tempresult.put(DATASUCCESS, SUCCESSFLAG);
                tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                tempresult.put(DATALIST_VUE,datalist);
                tempresult.put(DATATOTAL_VUE,total);
                tempresult.put(PAGESIZE_VUE,map.get(PAGESIZE_VUE)!=null?map.get(PAGESIZE_VUE):10);
                tempresult.put(DATACURRENT_VUE,map.get(DATACURRENT_VUE)!=null?map.get(DATACURRENT_VUE):0);
                result.put(DATARESULT, tempresult);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }



        @PostMapping( "/queryPageOracle")
        @ApiOperation(value="根据-{角色表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
            @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  queryPageOracleForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+""):1;
                int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                int pageStart = currentPage*pageSize ;


                map.put(PAGESTART,(currentPage-1)*pageSize);
                map.put(PAGEEND,currentPage*pageSize);

                int total = proAuthorityService.count(map);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proAuthorityService.queryPage(map);
                }
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST,datalist);
                Map<String, Object> pagemode = new HashMap<String, Object>();
                pagemode.put(DATATOTAL,total);
                pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                result.put(PAGINATION,pagemode);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{角色表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map统计查询总数记录",value = "query",type = "PC")
        public Map<String, Object>  countForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
                {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATATOTAL_VUE, proAuthorityService.count(map));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{角色表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map批量插入记录",value = "insert",type = "PC")
        public Map<String, Object>  insertBatchForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
                {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                for(Map<String, Object> map:list){
                map.put("auth_id", UUID.randomUUID().toString().replaceAll("-", ""));
                }

                proAuthorityService.insertBatch(list);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{角色表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map批量删除记录",value = "delete",type = "PC")
        public Map<String, Object>  deleteBatchForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
                {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                proAuthorityService.deleteBatch(list);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{角色表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_name", value = "角色名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "display", value = "是否显示", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "note", value = "备注", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "is_system_auth", value = "是否系统角色", required = true,  dataTypeClass = Integer.class),
        @ApiImplicitParam(paramType="body", name = "creator_id", value = "创建用户", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "parent_id", value = "父节点Id", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{角色表}-对象Map批量更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateBatchForProAuthorityForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
                {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                proAuthorityService.updateBatch(list);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

}
