package com.philisense.www.controller.web;

import com.philisense.www.annotation.log.OperateLog;
import com.philisense.www.common.config.CommonConst;
import com.philisense.www.controller.BaseUtilController;
import com.philisense.www.service.ProDeptService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX + "prodept")
@Api(tags = "ProDeptControllerForWeb|一个用来操作-{部门表}-业务模块的控制器")
public class ProDeptControllerForWeb extends BaseUtilController {

    @Autowired
    private ProDeptService proDeptService;


    @GetMapping("/delete")
    @ApiOperation(value = "根据-{部门表}-主键删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParam(paramType = "query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
    @OperateLog(name = "根据-{部门表}-主键删除记录", value = "delete", type = "PC")
    public Map<String, Object> deleteByPrimaryKeyForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestParam String recordid) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            Map<String, Object> one = proDeptService.getOne(new HashMap<String, Object>() {{
                put("dept_id", recordid);
            }});
//            int flag = proDeptService.deleteByPrimaryKey(recordid);
            int flag = 0;
            if(one != null) {
                flag = proDeptService.deleteByMap(new HashMap<String, Object>() {{
                    put("levelcode", one.get("levelcode"));
                }});
            }
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @GetMapping("/get")
    @ApiOperation(value = "根据-{部门表}-主键查询记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParam(paramType = "body", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
    @OperateLog(name = "根据-{部门表}-主键查询记录", value = "query", type = "PC")
    public Map<String, Object> selectByPrimaryKeyForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestParam String recordid) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARECORD, proDeptService.selectByPrimaryKey(recordid));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/insert")
    @ApiOperation(value = "根据-{部门表}-对象插入记录", notes = "成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象插入记录", value = "insert", type = "PC")
    public Map<String, Object> insertForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            Object dept_code = map.get("dept_code");
            Map<String, Object> paramMap = new HashMap<>();
            paramMap.put("dept_code", dept_code.toString());
            Map<String, Object> one = proDeptService.getOne(paramMap);
            if (null != one) {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, INSERT_FAIL_MSG + "部门代码已存在");
                return result;
            }
            String ID = UUID.randomUUID().toString().replaceAll("-", "");
            map.put("dept_id", ID);
            map.put("id", ID);
            map.put("code", dept_code);
            map.put("value", dept_code);
            map.put("title", map.get("dept_name"));
            map.put("levelcode", map.get("parentlevelcode") + "/" + ID);
            proDeptService.insert(map);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
            result.put(DATARECORD, map);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/update")
    @ApiOperation(value = "根据-{部门表}-对象更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象更新记录", value = "update", type = "PC")
    public Map<String, Object> updateForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


            String ID = map.get("dept_id") + "";
            if (ID.equals("")) {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG + "记录ID不能为空");
                return result;
            }
            Map<String, Object> temmap = proDeptService.selectByPrimaryKey(ID);

            if (null == temmap || temmap.size() == 0) {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG + ID + "记录不存在");
                return result;
            }

            Object dept_code = map.get("dept_code");
            Map<String, Object> paramMap = new HashMap<>();
            paramMap.put("dept_code", dept_code.toString());
            List<Map<String, Object>> nameAll = proDeptService.getAll(paramMap);
            if (null != nameAll && !nameAll.isEmpty()) {
                if (1 == nameAll.size()) {
                    Map<String, Object> prodept = nameAll.get(0);
                    if (!prodept.get("dept_id").equals(map.get("dept_id"))) {
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, INSERT_FAIL_MSG + "部门代码已存在！");
                        return result;
                    }
                } else {
                    result.put(DATASUCCESS, ERRORFLAG);
                    result.put(DATAMESSAGE, INSERT_FAIL_MSG + "部门代码已存在！");
                    return result;
                }
            }

            temmap.putAll(map);

            int flag = proDeptService.update(temmap);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/deleteByMap")
    @ApiOperation(value = "根据-{部门表}-对象Map删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map删除记录", value = "delete", type = "PC")
    public Map<String, Object> deleteByMapForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            int flag = proDeptService.deleteByMap(map);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/updateByMap")
    @ApiOperation(value = "根据-{部门表}-对象Map更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map更新记录", value = "update", type = "PC")
    public Map<String, Object> updateByMapForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


            int flag = proDeptService.updateByMap(map);
            if (1 <= flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/getOne")
    @ApiOperation(value = "根据-{部门表}-对象Map查询记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map查询记录", value = "query", type = "PC")
    public Map<String, Object> getOneForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATARECORD, proDeptService.getOne(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/getAll")
    @ApiOperation(value = "根据-{部门表}-对象Map查询所有记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map查询所有记录", value = "query", type = "PC")
    public Map<String, Object> getAllForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATALIST_VUE, proDeptService.getAll(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping( "/queryPage")
    @ApiOperation(value="根据-{部门表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
        @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map分页记录",value = "query",type = "PC")
    public Map<String, Object>  queryPageForProDeptForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
    {
            Map<String, Object> result = new HashMap<String, Object>();
            try {

            int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
            int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
            int pageStart = currentPage*pageSize ;


            map.put(PAGESIZE,pageSize);
            map.put(PAGESTART,pageStart);

            int total = proDeptService.count(map);
            List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
            if(total>0){
            datalist = proDeptService.queryPage(map);
            }
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATALIST,datalist);
            Map<String, Object> pagemode = new HashMap<String, Object>();
            pagemode.put(DATATOTAL,total);
            pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
            pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
            result.put(PAGINATION,pagemode);
            }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
            }
            return result;
    }


    @PostMapping( "/queryPageVue")
    @ApiOperation(value="根据-{部门表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
        @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map分页记录",value = "query",type = "PC")
    public Map<String, Object>  queryPageVueForProDeptForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
    {
            Map<String, Object> result = new HashMap<String, Object>();
            try {

            int currentPage = map.get(DATACURRENT_VUE)!=null?Integer.parseInt(map.get(DATACURRENT_VUE)+"")-1:0;
            int pageSize = map.get(PAGESIZE_VUE)!=null?Integer.parseInt(map.get(PAGESIZE_VUE)+""):10;
            int pageStart = currentPage*pageSize ;


            map.put(PAGESIZE_VUE,pageSize);
            map.put(PAGESTART,pageStart);

            int total = proDeptService.count(map);
            List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
            if(total>0){
            datalist = proDeptService.queryPage(map);
            }
            Map<String, Object> tempresult = new HashMap<String, Object>();
            tempresult.put(DATASUCCESS, SUCCESSFLAG);
            tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            tempresult.put(DATALIST_VUE,datalist);
            tempresult.put(DATATOTAL_VUE,total);
            tempresult.put(PAGESIZE_VUE,map.get(PAGESIZE_VUE)!=null?map.get(PAGESIZE_VUE):10);
            tempresult.put(DATACURRENT_VUE,map.get(DATACURRENT_VUE)!=null?map.get(DATACURRENT_VUE):0);
            result.put(DATARESULT, tempresult);
            }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
            }
            return result;
    }



    @PostMapping( "/queryPageOracle")
    @ApiOperation(value="根据-{部门表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
        @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map分页记录",value = "query",type = "PC")
    public Map<String, Object>  queryPageOracleForProDeptForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
    {
            Map<String, Object> result = new HashMap<String, Object>();
            try {

            int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+""):1;
            int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
            int pageStart = currentPage*pageSize ;


            map.put(PAGESTART,(currentPage-1)*pageSize);
            map.put(PAGEEND,currentPage*pageSize);

            int total = proDeptService.count(map);
            List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
            if(total>0){
            datalist = proDeptService.queryPage(map);
            }
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATALIST,datalist);
            Map<String, Object> pagemode = new HashMap<String, Object>();
            pagemode.put(DATATOTAL,total);
            pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
            pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
            result.put(PAGINATION,pagemode);
            }catch(Exception e){
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
            }
            return result;
    }

    @PostMapping("/count")
    @ApiOperation(value = "根据-{部门表}-对象Map统计查询总数记录", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map统计查询总数记录", value = "query", type = "PC")
    public Map<String, Object> countForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATATOTAL_VUE, proDeptService.count(map));
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/insertBatch")
    @ApiOperation(value = "根据-{部门表}-对象Map批量插入记录", notes = "成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map批量插入记录", value = "insert", type = "PC")
    public Map<String, Object> insertBatchForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            for (Map<String, Object> map : list) {
                map.put("dept_id", UUID.randomUUID().toString().replaceAll("-", ""));
            }

            proDeptService.insertBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, INSERT_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/deleteBatch")
    @ApiOperation(value = "根据-{部门表}-对象Map批量删除记录", notes = "成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map批量删除记录", value = "delete", type = "PC")
    public Map<String, Object> deleteBatchForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            proDeptService.deleteBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, DELETE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/updateBatch")
    @ApiOperation(value = "根据-{部门表}-对象Map批量更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_id", value = "部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_name", value = "部门名称", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门code", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "parent_id", value = "父部门Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "leaf", value = "是否叶子", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "icon", value = "图标", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "cls", value = "层叠样式", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据-{部门表}-对象Map批量更新记录", value = "update", type = "PC")
    public Map<String, Object> updateBatchForProDeptForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody List<Map<String, Object>> list) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {


            proDeptService.updateBatch(list);
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }


    @PostMapping("/getProDeptTreeByParentid")
    @ApiOperation(value = "查询所有部门数据根据父节点id", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父部门ID", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "查询所有部门数据根据父节点id", value = "query", type = "PC")
    public Map<String, Object> getProDeptTreeByParentidForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            List<Map<String, Object>> treedata = proDeptService.getProDeptTreeByParentid(map);

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATALIST_VUE, treedata);


        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }


    @PostMapping("/getProDeptTreeByLevelCode")
    @ApiOperation(value = "查询所有部门数据根据层次码", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "parentid", value = "父部门ID", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "层次码", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "查询所有部门数据根据层次码", value = "query", type = "PC")
    public Map<String, Object> getProDeptTreeByLevelCodeForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {
            String parentid = map.get("parentid") + "";

            List<Map<String, Object>> treedata = proDeptService.getProDeptTreeByLevelCode(map);


            List<Map<String, Object>> parenttreedata = new ArrayList<Map<String, Object>>();


            if (null != treedata && treedata.size() > 0) {

                //一级树节点
                for (Map<String, Object> tree : treedata) {
                    tree.put("key", tree.get("dept_code"));

                    if (tree.get("parentid").equals(parentid)) {
                        parenttreedata.add(tree);
                    }
                }


                //二级树节点
                List<Map<String, Object>> second_treedata = new ArrayList<Map<String, Object>>();//二级树节点
                for (Map<String, Object> ptree : parenttreedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("dept_code"));
                        if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                            second_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }


                List<Map<String, Object>> third_treedata = new ArrayList<Map<String, Object>>();//三级树节点
                List<Map<String, Object>> fourth_treedata = new ArrayList<Map<String, Object>>();//四级树节点
                List<Map<String, Object>> fifth_treedata = new ArrayList<Map<String, Object>>();//五级树节点
                List<Map<String, Object>> sixth_treedata = new ArrayList<Map<String, Object>>();//六级树节点
                List<Map<String, Object>> seventh_treedata = new ArrayList<Map<String, Object>>();//七级树节点
                List<Map<String, Object>> eighth_treedata = new ArrayList<Map<String, Object>>();//八级树节点
                List<Map<String, Object>> nineth_treedata = new ArrayList<Map<String, Object>>();//九级树节点
                List<Map<String, Object>> tenth_treedata = new ArrayList<Map<String, Object>>();//十级树节点                  

                //三级树节点
                for (Map<String, Object> ptree : second_treedata) {
                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();

                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("dept_code"));
                        if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                            third_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }


                //四级树节点
                for (Map<String, Object> ptree : third_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("dept_code"));
                        if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                            fourth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }


                //五级树节点
                for (Map<String, Object> ptree : fourth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("dept_code"));
                        if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                            fifth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }


                //六级树节点
                for (Map<String, Object> ptree : fifth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("dept_code"));
                        if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                            sixth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }
                
                //七级树节点
                for (Map<String, Object> ptree : sixth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("dept_code"));

                        if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                        	seventh_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }
                //八级树节点
                for (Map<String, Object> ptree : seventh_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("dept_code"));

                        if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                        	eighth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }                
                
                //九级树节点
                for (Map<String, Object> ptree : eighth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("dept_code"));

                        if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                        	nineth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }                
                
                //十级树节点
                for (Map<String, Object> ptree : nineth_treedata) {

                    List<Map<String, Object>> sontreedata = new ArrayList<Map<String, Object>>();
                    for (Map<String, Object> tree : treedata) {
                        tree.put("key", tree.get("dept_code"));

                        if (tree.get("parentid").equals(ptree.get("dept_id"))) {
                        	tenth_treedata.add(tree);
                            sontreedata.add(tree);
                        }
                    }
                    ptree.put("children", sontreedata);
                }                
                

            }

            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATALIST_VUE, parenttreedata);


        } catch (Exception e) {

            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }


    @PostMapping("/getPageProUserByDeptCode")
    @ApiOperation(value = "根据部门代码查询用户列表", notes = "成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "dept_code", value = "部门代码", required = true,  dataTypeClass = String.class)
    })
    @OperateLog(name = "根据部门代码查询用户列表", value = "query", type = "PC")
    public Map<String, Object> getPageProUserByDeptCodeForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            int currentPage = map.get(DATACURRENT_VUE) != null ? Integer.parseInt(map.get(DATACURRENT_VUE) + "") - 1 : 0;
            int pageSize = map.get(PAGESIZE_VUE) != null ? Integer.parseInt(map.get(PAGESIZE_VUE) + "") : 10;
            int pageStart = currentPage * pageSize;

            map.put(PAGESIZE_VUE, pageSize);
            map.put(PAGESTART, pageStart);

            int total = proDeptService.getCountProUserByDeptCode(map);
            List<Map<String, Object>> datalist = new ArrayList<>();
            if (total > 0) {
                datalist = proDeptService.getPageProUserByDeptCode(map);
            }
            result.put(DATASUCCESS, SUCCESSFLAG);
            result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
            result.put(DATALIST_VUE, datalist);
            Map<String, Object> pagemode = new HashMap<>();
            pagemode.put(DATATOTAL_VUE, total);
            pagemode.put(PAGESIZE_VUE, map.get(PAGESIZE_VUE) != null ? map.get(PAGESIZE_VUE) : 10);
            pagemode.put(DATACURRENT_VUE, map.get(DATACURRENT_VUE) != null ? map.get(DATACURRENT_VUE) : 0);
            result.put(PAGINATION, pagemode);

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, QUERY_FAIL_MSG + e.getMessage());
        }
        return result;
    }

    @PostMapping("/updateDropNode")
    @ApiOperation(value = "根据-{来源节点与目标节点}-对象更新记录", notes = "成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "source_id", value = "来源部门ID", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "source_parentid", value = "来源部门父ID", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "target_id", value = "目标会部门ID", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType = "body", name = "levelcode", value = "修改后的层次码", required = true,  dataTypeClass = String.class),
    })
    @OperateLog(name = "根据-{来源节点与目标节点}-对象更新记录", value = "update", type = "PC")
    public Map<String, Object> updateDropNodeForWeb(HttpServletRequest request, HttpServletResponse response, @RequestBody Map<String, Object> map) {
        Map<String, Object> result = new HashMap<String, Object>();
        try {

            Map<String, Object> temp = new HashMap<String, Object>();

            temp.put("id", map.get("source_id"));
            temp.put("source_parentid", map.get("source_parentid"));
            temp.put("parentid", map.get("target_id"));
            temp.put("levelcode", map.get("levelcode"));

            Map<String, Object> paramsmap = proDeptService.selectByPrimaryKey(map.get("source_id") + "");

            int flag = 0;

            if (null != paramsmap && paramsmap.size() > 0) {
                paramsmap.putAll(temp);
                flag = proDeptService.updateDropNode(paramsmap);
            }
            if (1 <= flag) {
                // 修改子节点 levelcode
                proDeptService.updateBatchLevelCode(new HashMap<String, Object>() {{
                    put("source_levelcode", map.get("source_levelcode"));
                    put("levelcode", map.get("levelcode"));
                }});
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                result.put(DATARECORD, paramsmap);
            } else {
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
            }

        } catch (Exception e) {
            result.put(DATASUCCESS, ERRORFLAG);
            result.put(DATAMESSAGE, UPDATE_FAIL_MSG + e.getMessage());
        }
        return result;
    }

}
