package com.philisense.www.controller.web;

import com.philisense.www.common.config.CommonConst;
import com.philisense.www.service.ProUserAuthService;
import com.philisense.www.annotation.log.OperateLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.philisense.www.controller.BaseUtilController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(CommonConst.WEB_REST_SERVICE_PREFICX+"prouserauth")
@Api(tags = "ProUserAuthControllerForWeb|一个用来操作-{用于角色表}-业务模块的控制器")
public class ProUserAuthControllerForWeb extends BaseUtilController{

        @Autowired
        private ProUserAuthService proUserAuthService;


        @GetMapping( "/delete")
        @ApiOperation(value="根据-{用于角色表}-主键删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{用于角色表}-主键删除记录",value = "delete",type = "PC")
        public Map<String, Object> deleteByPrimaryKeyForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                int flag = proUserAuthService.deleteByPrimaryKey(recordid);
                if(1<=flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @GetMapping( "/get")
        @ApiOperation(value="根据-{用于角色表}-主键查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParam(paramType="query", name = "recordid", value = "记录主键", required = true,  dataTypeClass = String.class)
        @OperateLog(name = "根据-{用于角色表}-主键查询记录",value = "query",type = "PC")
        public Map<String, Object> selectByPrimaryKeyForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestParam String recordid)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATARECORD, proUserAuthService.selectByPrimaryKey(recordid));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insert")
        @ApiOperation(value="根据-{用于角色表}-对象插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象插入记录",value = "insert",type = "PC")
        public Map<String, Object>  insertForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                map.put("user_id", UUID.randomUUID().toString().replaceAll("-", ""));
                map.put("auth_id", UUID.randomUUID().toString().replaceAll("-", ""));
                proUserAuthService.insert(map);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/update")
        @ApiOperation(value="根据-{用于角色表}-对象更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                int flag = proUserAuthService.update(map);
                if(1<=flag){
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteByMap")
        @ApiOperation(value="根据-{用于角色表}-对象Map删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map删除记录",value = "delete",type = "PC")
        public Map<String, Object>  deleteByMapForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                int flag = proUserAuthService.deleteByMap(map);
                if(1<=flag) {
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateByMap")
        @ApiOperation(value="根据-{用于角色表}-对象Map更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateByMapForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                int flag = proUserAuthService.updateByMap(map);
                if(1<=flag){
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);
                }else{
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG);
                }

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }
        @PostMapping( "/getOne")
        @ApiOperation(value="根据-{用于角色表}-对象Map查询记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"datarecord\":\"{}\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map查询记录",value = "query",type = "PC")
        public Map<String, Object>  getOneForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATARECORD, proUserAuthService.getOne(map));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/getAll")
        @ApiOperation(value="根据-{用于角色表}-对象Map查询所有记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map查询所有记录",value = "query",type = "PC")
        public Map<String, Object>  getAllForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
                {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST_VUE, proUserAuthService.getAll(map));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/queryPage")
        @ApiOperation(value="根据-{用于角色表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  queryPageForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                int pageStart = currentPage*pageSize ;


                map.put(PAGESIZE,pageSize);
                map.put(PAGESTART,pageStart);

                int total = proUserAuthService.count(map);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proUserAuthService.queryPage(map);
                }
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST,datalist);
                Map<String, Object> pagemode = new HashMap<String, Object>();
                pagemode.put(DATATOTAL,total);
                pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                result.put(PAGINATION,pagemode);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }


        @PostMapping( "/queryPageVue")
        @ApiOperation(value="根据-{用于角色表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  queryPageVueForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                int currentPage = map.get(DATACURRENT_VUE)!=null?Integer.parseInt(map.get(DATACURRENT_VUE)+"")-1:0;
                int pageSize = map.get(PAGESIZE_VUE)!=null?Integer.parseInt(map.get(PAGESIZE_VUE)+""):10;
                int pageStart = currentPage*pageSize ;


                map.put(PAGESIZE_VUE,pageSize);
                map.put(PAGESTART,pageStart);

                int total = proUserAuthService.count(map);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proUserAuthService.queryPage(map);
                }
                Map<String, Object> tempresult = new HashMap<String, Object>();
                tempresult.put(DATASUCCESS, SUCCESSFLAG);
                tempresult.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                tempresult.put(DATALIST_VUE,datalist);
                tempresult.put(DATATOTAL_VUE,total);
                tempresult.put(PAGESIZE_VUE,map.get(PAGESIZE_VUE)!=null?map.get(PAGESIZE_VUE):10);
                tempresult.put(DATACURRENT_VUE,map.get(DATACURRENT_VUE)!=null?map.get(DATACURRENT_VUE):0);
                result.put(DATARESULT, tempresult);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }



        @PostMapping( "/queryPageOracle")
        @ApiOperation(value="根据-{用于角色表}-对象Map分页记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
            @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
            @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map分页记录",value = "query",type = "PC")
        public Map<String, Object>  queryPageOracleForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+""):1;
                int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                int pageStart = currentPage*pageSize ;


                map.put(PAGESTART,(currentPage-1)*pageSize);
                map.put(PAGEEND,currentPage*pageSize);

                int total = proUserAuthService.count(map);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proUserAuthService.queryPage(map);
                }
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST,datalist);
                Map<String, Object> pagemode = new HashMap<String, Object>();
                pagemode.put(DATATOTAL,total);
                pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                result.put(PAGINATION,pagemode);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/count")
        @ApiOperation(value="根据-{用于角色表}-对象Map统计查询总数记录", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map统计查询总数记录",value = "query",type = "PC")
        public Map<String, Object>  countForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
                {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATATOTAL_VUE, proUserAuthService.count(map));
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/insertBatch")
        @ApiOperation(value="根据-{用于角色表}-对象Map批量插入记录", notes="成功返回:{\"success\":true,\"message\",\"数据插入成功\"},失败返回:{\"success\":false,\"message\",\"数据插入失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map批量插入记录",value = "insert",type = "PC")
        public Map<String, Object>  insertBatchForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
                {
                Map<String, Object> result = new HashMap<String, Object>();
                try {



                        List<Map<String, Object>> list = (List)map.get("authids");
                        if(null!=list && list.size()>0) {
                                proUserAuthService.deleteBatch(list);//先把角色与用户删除
                        }
                        List<Map<String, Object>> list1 = (List)map.get("authids_userids");
                        if(null!=list1 && list1.size()>0) {
                                proUserAuthService.insertBatch(list1);//再重新插入角色和用户
                        }
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, INSERT_SUCCESS_MSG);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, INSERT_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/deleteBatch")
        @ApiOperation(value="根据-{用于角色表}-对象Map批量删除记录", notes="成功返回:{\"success\":true,\"message\",\"数据删除成功\"},失败返回:{\"success\":false,\"message\",\"数据删除失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map批量删除记录",value = "delete",type = "PC")
        public Map<String, Object>  deleteBatchForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
                {
                Map<String, Object> result = new HashMap<String, Object>();
                try {
                proUserAuthService.deleteBatch(list);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, DELETE_SUCCESS_MSG);

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, DELETE_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/updateBatch")
        @ApiOperation(value="根据-{用于角色表}-对象Map批量更新记录", notes="成功返回:{\"success\":true,\"message\",\"数据更新成功\"},失败返回:{\"success\":false,\"message\",\"数据更新失败\"}")
        @ApiImplicitParams({
        @ApiImplicitParam(paramType="body", name = "user_id", value = "用户Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色Id", required = true,  dataTypeClass = String.class),
        @ApiImplicitParam(paramType="body", name = "auth_type", value = "角色类型", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据-{用于角色表}-对象Map批量更新记录",value = "update",type = "PC")
        public Map<String, Object>  updateBatchForProUserAuthForWeb(HttpServletRequest request , HttpServletResponse response,@RequestBody List<Map<String, Object>> list)
                {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                proUserAuthService.updateBatch(list);
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, UPDATE_SUCCESS_MSG);

                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, UPDATE_FAIL_MSG+e.getMessage());
                }
                return result;
        }




        @PostMapping( "/getPageProUserByAuthId")
        @ApiOperation(value="根据角色ID查询用户列表", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色ID", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据角色ID查询用户列表",value = "query",type = "PC")
        public Map<String, Object>  getPageProUserByAuthId(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {

                
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                    Map<String, Object> mapauthids = new HashMap<String, Object>();
                    StringBuilder sb = new StringBuilder();
                    List<String> list = (List<String>) map.get("auth_id");
                    if(null!=list && list.size()>0){
                            for(String s:list){
                                    sb.append("'").append(s).append("'").append(",");
                            }
                            mapauthids.put("auth_id",sb.append("''").toString());
                    }
                int currentPage = map.get(DATACURRENT)!=null?Integer.parseInt(map.get(DATACURRENT)+"")-1:0;
                int pageSize = map.get(PAGESIZE)!=null?Integer.parseInt(map.get(PAGESIZE)+""):10;
                int pageStart = currentPage*pageSize ;



                mapauthids.put(PAGESIZE_VUE,pageSize);
                mapauthids.put(PAGESTART,pageStart);

                int total = proUserAuthService.getCountProUserByAuthId(mapauthids);
                List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                if(total>0){
                datalist = proUserAuthService.getPageProUserByAuthId(mapauthids);
                }
                result.put(DATASUCCESS, SUCCESSFLAG);
                result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                result.put(DATALIST,datalist);
                Map<String, Object> pagemode = new HashMap<String, Object>();
                pagemode.put(DATATOTAL,total);
                pagemode.put(PAGESIZE,map.get(PAGESIZE)!=null?map.get(PAGESIZE):10);
                pagemode.put(DATACURRENT,map.get(DATACURRENT)!=null?map.get(DATACURRENT):0);
                result.put(PAGINATION,pagemode);
                }catch(Exception e){
                result.put(DATASUCCESS, ERRORFLAG);
                result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;               
                
        }
        @PostMapping( "/getPageProUserByAuthIdVue")
        @ApiOperation(value="根据角色ID查询用户列表", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色ID", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "根据角色ID查询用户列表",value = "query",type = "PC")
        public Map<String, Object>  getPageProUserByAuthIdVue(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {


                        Map<String, Object> mapauthids = new HashMap<String, Object>();
                        StringBuilder sb = new StringBuilder();
                        List<String> list = (List<String>) map.get("auth_id");
                        if(null!=list && list.size()>0){
                                for(String s:list){
                                        sb.append("'").append(s).append("'").append(",");
                                }
                                mapauthids.put("auth_id",sb.append("''").toString());
                        }
                        int currentPage = map.get(DATACURRENT_VUE)!=null?Integer.parseInt(map.get(DATACURRENT_VUE)+"")-1:0;
                        int pageSize = map.get(PAGESIZE_VUE)!=null?Integer.parseInt(map.get(PAGESIZE_VUE)+""):10;
                        int pageStart = currentPage*pageSize ;

                        mapauthids.put(PAGESIZE_VUE,pageSize);
                        mapauthids.put(PAGESTART,pageStart);
                        int total = proUserAuthService.getCountProUserByAuthId(mapauthids);
                        List<Map<String, Object>> datalist = new ArrayList<Map<String, Object>>();
                        if(total>0){
                                datalist = proUserAuthService.getPageProUserByAuthId(mapauthids);
                        }
                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST_VUE,datalist);
                        Map<String, Object> pagemode = new HashMap<String, Object>();
                        pagemode.put(DATATOTAL_VUE,total);
                        pagemode.put(PAGESIZE_VUE,map.get(PAGESIZE_VUE)!=null?map.get(PAGESIZE_VUE):10);
                        pagemode.put(DATACURRENT_VUE,map.get(DATACURRENT_VUE)!=null?map.get(DATACURRENT_VUE):0);
                        result.put(PAGINATION,pagemode);

                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }

        @PostMapping( "/getSelectedProUserByAuthId")
        @ApiOperation(value="查询所有用户数据根据角色id", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色ID", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "查询所有用户数据根据角色id",value = "query",type = "PC")
        public Map<String, Object>  getSelectedProUserByAuthId(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        StringBuilder sb = new StringBuilder();
                        Map<String, Object> mapauthids = new HashMap<String, Object>();
                        List<String> list = (List<String>) map.get("auth_id");
                        if(null!=list && list.size()>0){
                                for(String s:list){
                                        sb.append("'").append(s).append("'").append(",");
                                }
                                mapauthids.put("auth_id",sb.append("''").toString());
                        }
                        List<Map<String,Object>> data = proUserAuthService.getPageProUserByAuthId(mapauthids);
                        List<String> datalist = new ArrayList<String>();

                        if( null!=data && data.size()>0 ){
                                for(Map<String,Object> temp:data){
                                        datalist.add(temp.get("user_id")+"");
                                }
                        }

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST,datalist);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }
        
        @PostMapping( "/getSelectedProUserByAuthIdVue")
        @ApiOperation(value="查询所有用户数据根据角色id", notes="成功返回:{\"success\":true,\"message\",\"数据查询成功\",\"data\":\"[]\"},失败返回:{\"success\":false,\"message\",\"数据查询失败\"}")
        @ApiImplicitParams({
                @ApiImplicitParam(paramType="body", name = "auth_id", value = "角色ID", required = true,  dataTypeClass = String.class)
        })
        @OperateLog(name = "查询所有用户数据根据角色id",value = "query",type = "PC")
        public Map<String, Object>  getSelectedProUserByAuthIdVue(HttpServletRequest request , HttpServletResponse response,@RequestBody Map<String, Object> map)
        {
                Map<String, Object> result = new HashMap<String, Object>();
                try {

                        StringBuilder sb = new StringBuilder();
                        Map<String, Object> mapauthids = new HashMap<String, Object>();
                        List<String> list = (List<String>) map.get("auth_id");
                        if(null!=list && list.size()>0){
                                for(String s:list){
                                        sb.append("'").append(s).append("'").append(",");
                                }
                                mapauthids.put("auth_id",sb.append("''").toString());
                        }
                        List<Map<String,Object>> data = proUserAuthService.getPageProUserByAuthId(mapauthids);
                        List<String> datalist = new ArrayList<String>();

                        if( null!=data && data.size()>0 ){
                                for(Map<String,Object> temp:data){
                                        datalist.add(temp.get("user_id")+"");
                                }
                        }

                        result.put(DATASUCCESS, SUCCESSFLAG);
                        result.put(DATAMESSAGE, QUERY_SUCCESS_MSG);
                        result.put(DATALIST_VUE,datalist);
                }catch(Exception e){
                        result.put(DATASUCCESS, ERRORFLAG);
                        result.put(DATAMESSAGE, QUERY_FAIL_MSG+e.getMessage());
                }
                return result;
        }       
        

}
